# object-oriented-bootstrap-modal

Create completely standalone, shadow-DOM encapsulated bootstrap in JavaScript! This is especially well suited for
Userscript / Browser extension developers.

## Installation

### NPM

First, install it from npm: `npm i object-oriented-bootstrap-modal`

Import the main class: `import {ObjectOrientedBootstrapModal} from 'object-oriented-bootstrap-modal`

### CDN

A bundle.js file is provided for your convenience.

For example, to import `https://cdn.jsdelivr.net/npm/object-oriented-bootstrap-modal/bundle.js` as an ES module, either
by:

```js
import {ObjectOrientedBootstrapModal} from 'https://cdn.jsdelivr.net/npm/object-oriented-bootstrap-modal/bundle.js';
```

in a module type JS, or dynamically import like:

```js
import('https://cdn.jsdelivr.net/npm/object-oriented-bootstrap-modal/bundle.js').then(({ObjectOrientedBootstrapModal}) => {
    // ..do what you want with ObjectOrientedBootstrapModal
});
```

in any JS.

## Use

You can either instantiate the ObjectOrientedBootstrapModal class as is, or subclass it to suit your own needs.

Check out test.html for an example:

```js
import {ObjectOrientedBootstrapModal} from "./bundle.js";

const modal = new ObjectOrientedBootstrapModal({
    content: '<p>Woohoo, you did it!</p>',
    header: 'New Modal'
});

modal.onConfirm = () => {
    alert('Meow');
};

document.getElementById('button').addEventListener('click', () => {
    modal.open();
});
```

Or to try something a bit more elaborate:

```tsx
import {ObjectOrientedBootstrapModal} from "...";

export class MyModal extends ObjectOrientedBootstrapModal {
    constructor() {
        super({
            header: 'My super duper title'
        });
    }
    
    open() {
        super.open();
        ReactDOM.render(<FooComponent />, this.content);
    }
    
    close() {
        ReactDOM.unmountComponentAtNode(this.content);
        super.close();
    }
}

const FooComponent: React.FC = () => {
    return <h1>Hello world...</h1>
}
```
