import {ElementContainer} from "./element-container";
import {ElementContainerFactory} from "./element-container-factory";
import {EscListener} from "./esc-listener";

export class ObjectOrientedBootstrapModal {

    private container: ElementContainer;
    private escListener = new EscListener(this);

    constructor(config: OOBMConfig) {
        this.container = new ElementContainerFactory(config).createContainer();
        this.container.addConfirmButtonListener(() => this.onConfirm());
        this.container.addCloseButtonListener(this.close.bind(this));
    }

    public open() {
        this.container.insertSelf();
        this.escListener.engage();
    }

    public close() {
        this.container.removeSelf();
        this.escListener.disengage();
    }

    protected get content(): HTMLElement {
        return this.container.getContentElement();
    }

    protected onConfirm = () => {
        // meant to be handled by subclasses
    };

}

export interface OOBMConfig {
    header: string;
    content: string | HTMLElement | undefined;
}
